@@ -19,9 +19,11 @@
 language_list=(
     '"Brazilian Portuguese" pt_BR'
     '"Czech"      cs'
+    '"Danish"     da'
     '"Dutch"      nl'
     '"French"     fr'
     '"German"     de'
+    '"Hungarian"  hu'
     '"Italian"    it'
     '"Macedonian" mk'
     '"Polish"     pl'
